@@ -18,10 +18,6 @@ use crate::{
 #[allow(clippy::large_enum_variant)]
 #[derive(Clone, Debug, PartialEq)]
 pub(crate) enum Proposal {
-    Online {
-        node_state: NodeState,
-        dst_key: Option<bls::PublicKey>,
-    },
     Offline(NodeState),
     SectionInfo(SectionAuthorityProvider),
     OurElders(SectionAuth<SectionAuthorityProvider>),
@@ -46,7 +42,6 @@ impl Proposal {
 
     pub(crate) fn as_signable_bytes(&self) -> Result<Vec<u8>> {
         Ok(match self {
-            Self::Online { node_state, .. } => bincode::serialize(node_state),
             Self::Offline(node_state) => bincode::serialize(node_state),
             Self::SectionInfo(info) => bincode::serialize(info),
             Self::OurElders(info) => bincode::serialize(&info.sig.public_key),
@@ -61,13 +56,6 @@ impl Proposal {
 impl Proposal {
     pub(crate) fn into_msg(self) -> ProposalMsg {
         match self {
-            Self::Online {
-                node_state,
-                dst_key,
-            } => ProposalMsg::Online {
-                node_state: node_state.to_msg(),
-                dst_key,
-            },
             Self::Offline(node_state) => ProposalMsg::Offline(node_state.to_msg()),
             Self::SectionInfo(sap) => ProposalMsg::SectionInfo(sap.to_msg()),
             Self::OurElders(sap) => ProposalMsg::OurElders(sap.into_authed_msg()),
@@ -79,13 +67,6 @@ impl Proposal {
 impl ProposalMsg {
     pub(crate) fn into_state(self) -> Proposal {
         match self {
-            Self::Online {
-                node_state,
-                dst_key,
-            } => Proposal::Online {
-                node_state: node_state.into_state(),
-                dst_key,
-            },
             Self::Offline(node_state) => Proposal::Offline(node_state.into_state()),
             Self::SectionInfo(sap) => Proposal::SectionInfo(sap.into_state()),
             Self::OurElders(sap) => Proposal::OurElders(sap.into_authed_state()),
