@@ -8,8 +8,8 @@
 
 use std::mem;
 
-use crate::messaging::{system::SectionAuth, SectionAuthorityProvider};
-use crate::routing::dkg::KeyedSig;
+use crate::messaging::system::SectionAuth;
+use crate::routing::{dkg::KeyedSig, network_knowledge::SectionAuthorityProvider};
 use xor_name::Prefix;
 
 type Entry = (SectionAuth<SectionAuthorityProvider>, KeyedSig);
@@ -29,13 +29,14 @@ impl SplitBarrier {
     //
     // Note: in case of a fork, it can return more than two proposals. In that case one of the
     // proposals will be for one subsection and all the others for the other subsection.
+    #[instrument(skip(self), level = "trace", name = "split barrier processing")]
     pub(crate) fn process(
         &mut self,
         our_prefix: &Prefix,
         section_auth: SectionAuth<SectionAuthorityProvider>,
         keyed_sig: KeyedSig,
     ) -> Vec<Entry> {
-        if !section_auth.value.prefix.is_extension_of(our_prefix) {
+        if !section_auth.prefix().is_extension_of(our_prefix) {
             // Not a split, no need to cache.
             return vec![(section_auth, keyed_sig)];
         }
@@ -45,7 +46,7 @@ impl SplitBarrier {
             mem::take(&mut self.0)
                 .into_iter()
                 .partition(|(cached_section_auth, _)| {
-                    cached_section_auth.value.prefix == section_auth.value.prefix.sibling()
+                    cached_section_auth.prefix() == section_auth.prefix().sibling()
                 });
         self.0 = keep;
 
